from THP_Sensing.displaythp import display
from THP_Sensing.datamgmt import datamgmt
from THP_Sensing.jsondata import jsondata
from THP_Sensing.test import welcome
from THP_Sensing.thpdisplay import datadisplay


import csv
import json

def jsondata():
    csvFilepath = "Avg/avgTHPAll.csv"
    jsonFilepath = "Json/avgTHPAll.json"

    data = {}
    with open(csvFilepath) as csvFile:
        csvReader = csv.DictReader(csvFile)
        for csvRow in csvReader:
            sl_no = csvRow['Sl No.']
            data[sl_no] = csvRow

    with open('Json/avgTHPAll.json', 'w') as jsonFile:
        jsonFile.write(json.dumps(data, indent=4))
        